<?php

/*
 * Implements ctools hook mcapi_default_forms
 * N.B. Because ctools doesn't seem to run cache as well as might be expected, this is called any time a form is needed
 * Also: these are saved in the menu item arguments which may cause unexpected cacheing behaviour
 */
function cforge_currencies_mcapiforms_default_alter() {
  $forms = array('1stparty', '3rdparty');
  foreach ($forms as $form_id) {
    $function = 'cforge_default_'.$form_id;
    $mcapiforms[$form_id] = $function();
  }
  return $mcapiforms;
}

function cforge_default_1stparty() {
  $currencies = &drupal_static('currencies');
  $mcapiform = new stdClass;
  $mcapiform->disabled = FALSE; /* Edit this to true to make a default mcapi_form disabled initially */
  $mcapiform->api_version = 3;
  $mcapiform->name = '1stparty';
  $mcapiform->data = array(
    'info' => array(
      'name' => '1stparty',
    ),
    'perspective' => '1',
    'architecture' => array(
      'path' => 'transact/1stparty',
      'access' => 'user_access:transact',
      'menu_link' => MENU_DEFAULT_LOCAL_TASK,
      'use_block' => 1,
    ),
    'secondperson' => array(
      'preset' => '',
      'args' => 'user_chooser_permissions:transact',
    ),
    'direction' => array(
      'preset' => 'outgoing',
      'incoming' => 'I am requesting',
      'outgoing' => 'I am receiving',
      'widget' => 'radios',
    ),
    'worth' => array(
      'preset' => array(
        'und' => array(
          0 => array(
            'currcode' => 'def_drup',
            'quantity' => '1',
          ),
        ),
        'disable' => 0,
        'required' => 1,
      ),
    ),
    'submission' => array(
      'button' => 'Submit',
      'redirect' => 'user/%user/transactions',
      'feedback' => t('The transaction will be finalised when the other user signs it.')
    ),
    'experience' => array(
      'title' => 'Record an exchange',
      'template' => 'Partner: [mcapiform:secondperson]<br />
    Direction: [mcapiform:direction]<br />
    Amount: [mcapiform:worth]<br />',
      'sure_title' => 'Are you sure?',
      'sure_format' => 'certificate',
    ),
    'buttons' => array(
      'submit' => 'Save',
      'delete' => 'Revert',
    ),
  );
  return $mcapiform;
}

function cforge_default_3rdparty() {
  $currencies = &drupal_static('currencies');
  $mcapiform = new stdClass;
  $mcapiform->disabled = FALSE; /* Edit this to true to make a default form disabled initially */
  $mcapiform->api_version = 3;
  $mcapiform->name = '3rdparty';
  $mcapiform->data = array(
    'info' => array(
      'name' => '3rdparty',
    ),
    'perspective' => '3',
    'architecture' => array(
      'path' => 'transact/3rdparty',
      'access' => 'user_access:manage all transactions',
      'menu_link' => MENU_LOCAL_TASK,
      'use_block' => 1,
    ),
    'payer' => array(
      'preset' => '',
      'args' => 'user_chooser_permissions:transact',
      'multiple' => 0,
    ),
    'payee' => array(
      'preset' => '',
      'args' => 'user_chooser_permissions:transact',
      'multiple' => 0,
    ),
    'worth' => array(
      'preset' => array(
        'und' => array(
          0 => array(
            'currcode' => 'def_drup',
            'quantity' => '0',
          ),
        ),
      ),
    ),
    'submission' => array(
      'button' => 'Submit',
      'redirect' => 'transaction/%transaction',
    ),
    'experience' => array(
      'title' => 'Record a transaction',
      'template' => 'Payer: [mcapiform:payer]<br />
Payee: [mcapiform:payee]<br />
Amount: [mcapiform:worth]<br />',
      'sure_title' => 'Are you sure?',
      'sure_format' => 'certificate',
    ),
    'buttons' => array(
      'submit' => 'Save',
      'delete' => 'Revert',
    ),
  );
  return $mcapiform;
}

